@@ -59,8 +59,8 @@ class MYSQLExporter(Result):
         if not self.args.mysql: return
         import MySQLdb
         query=[ "update tw_user set tw_id=\'%s\', task_status=\'%s\', task_host=\'%s\', created_at=\'%s\', statuses_count=\'%s\', friend_count=\'%s\', followers_count=\'%s\', geo_lat=\'%s\', geo_long=\'%s\', geo_text=\'%s\' where  name=\'%s\'" ,
-                "Insert into tw_userfollower (user_tw_id, follower) values (%s,%s)",
-                "Insert into tw_frienduser (friend, user_tw_id) values (%s,%s)"
+                #"Insert into tw_userfollower (user_tw_id, follower) values (%s,%s)",
+                #"Insert into tw_frienduser (friend, user_tw_id) values (%s,%s)"
                 ]
         mysql=self.args.mysql.split(',') 
         try:
@@ -197,7 +197,8 @@ class ResultsGenerator(object):
                     print user_[0]
                     pass
 
-        return (myusers, myfollowers, myfriends)
+        #return (myusers, myfollowers, myfriends)
+        return (myusers)
 
     def process_data(self, get_html=False, obj=False):
         if not obj:
